from distutils.core import setup

setup(
    name='Whiffle',
    version='0.1.0',
    packages=['whiffle',],
    license='GNU Lesser General Public License v3 or later',
    description='A wrapper around the Wikidot XML-RPC API',
    long_description=open('README.txt').read(),
    author="Richard Urwin",
    author_email="soronlin.voyage+whiffle@googlemail.com",
    url="http://www.soronlin.org.uk/software:whiffle",
)

